@@ -17,62 +17,7 @@ sub customize {
     $model->output($_ => $model->input($_));
     $change_flag = 1;
   }
-  $model->pkit_gettext_message("Your changes have been made.") if $change_flag;
-}
-
-sub error_report {
-  warn "test warning message";
-}
-
-sub form_validation_done {
-  my $model = shift;
-  my $input_profile = {
-		       required => [ qw( email phone likes ) ],
-		       optional => [ qq( toppings ) ],
-		       constraints => {
-				       email => "email",
-				       phone => "phone",
-				      },
-		       messages => {
-				    email => "The E-mail address, <b>%%VALUE%%</b>, is invalid.",
-				    phone => "The phone number, <b>%%VALUE%%</b>, is invalid.",
-				   },
-		 };
-  # validate user input
-  unless($model->pkit_validate_input($input_profile)){
-    $model->pkit_internal_redirect('form_validation');
-    return;
-  }
-  $model->pkit_redirect('index');
-}
-
-sub index {
-  my $model = shift;
-
-  my $session_id = $model->pkit_get_session_id || '[Session not set]';
-  $model->output(session_id => $session_id);
-
-  my $pkit_server_id = $model->pkit_get_server_id;
-  $model->output(pkit_server_id => $pkit_server_id);
-}
-
-sub language {
-  my $model = shift;
-
-  my $pkit_lang = $model->pkit_lang;
-
-  $model->output(model_pkit_lang => $pkit_lang);
-}
-
-sub media {
-  my $model = shift;
-
-  # just for laughs, we display the process number
-  $model->output(process_number => $$);
-}
-
-sub media_xslt {
-  return shift->media;
+  $model->pkit_message("Your changes have been made.") if $change_flag;
 }
 
 sub newacct2 {
@@ -123,17 +68,17 @@ sub newacct2 {
   my $pkit_done = $model->input('pkit_done');
 
   # make up userID
-  my $user_id = substr(Digest::MD5::md5_hex(Digest::MD5::md5_hex(time(). {}. rand(). $$)), 0, 8);
+  my $user_id = substr(MD5->hexhash(MD5->hexhash(time(). {}. rand(). $$)), 0, 8);
 
   my $sql_str = "INSERT INTO pkit_user (user_id,email,login,passwd) VALUES (?,?,?,?)";
   $dbh->do($sql_str, {}, $user_id, $model->input('email'),
 				$login, $passwd);
 
   # example of pkit_message being passed along with pkit_redirect
-  $model->pkit_gettext_message("This message was passed throught pkit_redirect");
-  $model->pkit_gettext_message("Another message passed throught pkit_redirect");
+  $model->pkit_message("This message was passed throught pkit_redirect");
+  $model->pkit_message("Another message passed throught pkit_redirect");
 
-  $model->pkit_gettext_message("This ERROR message was passed throught pkit_redirect",
+  $model->pkit_message("This ERROR message was passed throught pkit_redirect",
 		      is_error => 1);
 
   $model->pkit_redirect("/?login=$login&passwd=$passwd&pkit_done=$pkit_done&pkit_login=1");
@@ -158,15 +103,13 @@ another for processing new account sign ups.
 
 It is a good starting point for building your backend for your PageKit website.
 
-=head1 AUTHORS
+=head1 AUTHOR
 
 T.J. Mather (tjmather@thoughtstore.com)
 
-Boris Zentner (boris@id9.de)
-
 =head1 COPYRIGHT
 
-Copyright (c) 2000, 2001, 2002 AnIdea Corp.  All rights Reserved.  PageKit is a trademark
+Copyright (c) 2000, AnIdea Corp.  All rights Reserved.  PageKit is a trademark
 of AnIdea, Corp.
 
 =head1 LICENSE
